# Epydoc Log

Epydoc started at Thu Jun 30 13:20:44 2011

## In /home/users/jajcus/git/pyxmpp2/build/lib/pyxmpp2/cache.py: No documentation available!

## In /home/users/jajcus/git/pyxmpp2/build/lib/pyxmpp2/roster.py: No documentation available!

## In /home/users/jajcus/git/pyxmpp2/build/lib/pyxmpp2/sasl/gssapi.py: Import failed (but source code parsing was successful).

Error: ImportError: No module named kerberos (line 29)

## File /home/users/jajcus/git/pyxmpp2/build/lib/pyxmpp2/simple.py, line 47, in pyxmpp2.simple.FireAndForget

Docstring Warning: @param for unknown parameter "client"
Docstring Warning:

    Failed identifier crossreference targets:
    - pyxmpp2.ext
          (from pyxmpp2)
    - xml_element_name
          (from ??.handler_key-1)

## Epydoc Options

configfiles | `=` | `['epydoc.cfg']`
docformat | `=` | `'restructuredtext'`
include_log | `=` | `True`
include_source_code | `=` | `False`
names | `=` | `['pyxmpp2']`
prj_name | `=` | `'PyXMPP2'`
prj_url | `=` | `'https://github.com/Jajcus/pyxmpp2/'`
show_frames | `=` | `False`
target | `=` | `'www/api'`
verbose | `=` | `1`
verbosity | `=` | `1`
action | `=` | `'html'`
css | `=` | `None`
debug | `=` | `False`
dotpath | `=` | `None`
exclude | `=` | `['(pyxmpp2\\.(roster|cache|ext\\..*)|abc$)']`
exclude_introspect | `=` | `[]`
exclude_parse | `=` | `[]`
external_api | `=` | `['etree', 'std', 'dns', 'r']`
external_api_file | `=` | `['etree:etree.txt', 'std:std.txt', 'dns:dns.txt', 'r:settings.txt']`
external_api_root | `=` | `['etree:http://docs.python.org/library/xml.etree.elementtree.html', 'std:http://docs.python.org/library/', 'dns:http://www.dnspython.org/docs/1.9.4/html/', 'r:../Settings.html']`
fail_on | `=` | `None`
graph_font | `=` | `None`
graph_font_size | `=` | `None`
graphs | `=` | `['classtree']`
help_file | `=` | `None`
inheritance | `=` | `'listed'`
introspect | `=` | `True`
list_classes_separately | `=` | `False`
load_pickle | `=` | `False`
parse | `=` | `True`
prj_link | `=` | `None`
profile | `=` | `False`
pstat_files | `=` | `[]`
quiet | `=` | `0`
redundant_details | `=` | `False`
show_imports | `=` | `False`
show_private | `=` | `True`
simple_term | `=` | `False`
src_code_tab_width | `=` | `8`
top_page | `=` | `None`

Epydoc finished at Thu Jun 30 13:21:21 2011

(Elapsed time: 36 seconds)